(api)=

# AnyPyTools API

## Userfacing API

### Processing

```{toctree}
:maxdepth: 2

AnyPyProcess
```

### Generating macros

```{toctree}
:maxdepth: 2

AnyMacro
macro_commands
```

### Reading AnyOutputFiles

```{toctree}
:maxdepth: 2

read_anyoutputfile
anyoutputfile_generator
```

### Reading anydatah5 (hdf5) files

```{toctree}
:maxdepth: 1

h5py_wrapper
anydatah5_generator
```

## All modules

```{toctree}
:maxdepth: 3

abcutils
datautils
macroutils
h5py_wrapper
pytest_plugin
tools
```
